@@ -30,7 +30,7 @@ class fMMS_GUI(hildon.Program):
 	def __init__(self):
 		""" Initializes the GUI, creating all widgets. """
 		self.cont = fMMSController.fMMS_controllerGTK()
-		self.config = fMMSconf.fMMS_config()
+		self.config = self.cont.config
 		self.ch = ContactH.ContactHandler()
 		
 		self.osso_c = osso.Context("se.frals.fmms", self.config.get_version(), False)
@@ -198,7 +198,7 @@ class fMMS_GUI(hildon.Program):
 				self.config.switcharoo()
 
 			self.take_ss()
-			
+
 		return True
 
 
@@ -267,22 +267,22 @@ class fMMS_GUI(hildon.Program):
 
 			isread = self.cont.is_mms_read(fname)
 
-			sender = varlist.get('From', '00000').replace("/TYPE=PLMN", "")
-
 			if direction == fMMSController.MSG_DIRECTION_OUT:
 				sender = self.cont.get_mms_headers(varlist['Transaction-Id'])
 				sender = sender['To'].replace("/TYPE=PLMN", "")
+			else:
+				sender = varlist.get('From', '00000').replace("/TYPE=PLMN", "")
 
 			sendernr = sender
 
-			senderuid = self.nrlist.get(sender, None)
-			if not senderuid:
+			senderuid = self.nrlist.get(sender, -1)
+			if senderuid == -1:
 				senderuid = self.ch.get_uid_from_number(sender)
 				self.nrlist[sender] = senderuid
 
 			avatar = default_avatar
-			# need to check against None as uid might be 0
-			if senderuid != None:
+			# compare with -1 as thats invalid contactuid
+			if senderuid != -1 and senderuid != None:
 				sender = self.namelist.get(senderuid, None)
 				if not sender:
 					sender = self.ch.get_displayname_from_uid(senderuid)
@@ -390,6 +390,7 @@ class fMMS_GUI(hildon.Program):
 
 	def show_mms(self, treeview, path):
 		""" Shows the message at the current selection in the treeview. """
+		self.treeview.set_sensitive(False)
 		# Show loading indicator
 		hildon.hildon_gtk_window_set_progress_indicator(self.window, 1)
 		self.force_ui_update()
@@ -417,6 +418,7 @@ class fMMS_GUI(hildon.Program):
 			log.exception("Failed to open viewer with transaction id: %s" % transactionid)
 			#raise
 		hildon.hildon_gtk_window_set_progress_indicator(self.window, 0)
+		self.treeview.set_sensitive(True)
 
 	def show_switch_conn_dialog(self):
 		""" Show confirmation dialog asking if we should disconnect """
